@@ -32,6 +32,7 @@ import importlib as _importlib
 
 from .feed import ChatFeed  # noqa
 from .icon import ChatReactionIcons  # noqa
+from .input import ChatAreaInput  # noqa
 from .interface import ChatInterface  # noqa
 from .message import ChatMessage  # noqa
 
@@ -45,6 +46,7 @@ def __getattr__(name):
     raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
 
 __all__ = (
+    "ChatAreaInput",
     "ChatFeed",
     "ChatInterface",
     "ChatMessage",
