@@ -9,10 +9,9 @@ import asyncio
 import traceback
 
 from enum import Enum
-from functools import partial
 from inspect import (
     isasyncgen, isasyncgenfunction, isawaitable, iscoroutinefunction,
-    isgenerator,
+    isgenerator, isgeneratorfunction,
 )
 from io import BytesIO
 from typing import (
@@ -23,11 +22,10 @@ import param
 
 from .._param import Margin
 from ..io.resources import CDN_DIST
-from ..layout import Column, ListPanel
+from ..layout import Feed, ListPanel
 from ..layout.card import Card
 from ..layout.spacer import VSpacer
 from ..pane.image import SVG
-from ..widgets.button import Button
 from .message import ChatMessage
 
 if TYPE_CHECKING:
@@ -35,61 +33,9 @@ if TYPE_CHECKING:
     from bokeh.model import Model
     from pyviz_comms import Comm
 
-USER_LOGO = "🧑"
-ASSISTANT_LOGO = "🤖"
-SYSTEM_LOGO = "⚙️"
-ERROR_LOGO = "❌"
-GPT_3_LOGO = "https://upload.wikimedia.org/wikipedia/commons/thumb/0/04/ChatGPT_logo.svg/1024px-ChatGPT_logo.svg.png?20230318122128"
-GPT_4_LOGO = "https://upload.wikimedia.org/wikipedia/commons/a/a4/GPT-4.png"
-WOLFRAM_LOGO = "https://upload.wikimedia.org/wikipedia/commons/thumb/e/eb/WolframCorporateLogo.svg/1920px-WolframCorporateLogo.svg.png"
-
-DEFAULT_AVATARS = {
-    # User
-    "client": USER_LOGO,
-    "customer": USER_LOGO,
-    "employee": USER_LOGO,
-    "human": USER_LOGO,
-    "person": USER_LOGO,
-    "user": USER_LOGO,
-    # Assistant
-    "agent": ASSISTANT_LOGO,
-    "ai": ASSISTANT_LOGO,
-    "assistant": ASSISTANT_LOGO,
-    "bot": ASSISTANT_LOGO,
-    "chatbot": ASSISTANT_LOGO,
-    "machine": ASSISTANT_LOGO,
-    "robot": ASSISTANT_LOGO,
-    # System
-    "system": SYSTEM_LOGO,
-    "exception": ERROR_LOGO,
-    "error": ERROR_LOGO,
-    # Human
-    "adult": "🧑",
-    "baby": "👶",
-    "boy": "👦",
-    "child": "🧒",
-    "girl": "👧",
-    "man": "👨",
-    "woman": "👩",
-    # Machine
-    "chatgpt": GPT_3_LOGO,
-    "gpt3": GPT_3_LOGO,
-    "gpt4": GPT_4_LOGO,
-    "dalle": GPT_4_LOGO,
-    "openai": GPT_4_LOGO,
-    "huggingface": "🤗",
-    "calculator": "🧮",
-    "langchain": "🦜",
-    "translator": "🌐",
-    "wolfram": WOLFRAM_LOGO,
-    "wolfram alpha": WOLFRAM_LOGO,
-    # Llama
-    "llama": "🦙",
-    "llama2": "🐪",
-}
 
 PLACEHOLDER_SVG = """
-    <svg xmlns="http://www.w3.org/2000/svg" class="icon icon-tabler icon-tabler-loader-3" width="40" height="40" viewBox="0 0 24 24" stroke-width="2" stroke="currentColor" fill="none" stroke-linecap="round" stroke-linejoin="round">
+    <svg xmlns="http://www.w3.org/2000/svg" class="icon icon-tabler icon-tabler-loader-3" width="35" height="35" viewBox="0 0 24 24" stroke-width="2" stroke="currentColor" fill="none" stroke-linecap="round" stroke-linejoin="round">
         <path stroke="none" d="M0 0h24v24H0z" fill="none"></path>
         <path d="M3 12a9 9 0 0 0 9 9a9 9 0 0 0 9 -9a9 9 0 0 0 -9 -9"></path>
         <path d="M17 12a5 5 0 1 0 -5 5"></path>
@@ -181,9 +127,22 @@ class ChatFeed(ListPanel):
     objects = param.List(default=[], doc="""
         The list of child objects that make up the layout.""")
 
+    help_text = param.String(default="", doc="""
+        If provided, initializes a chat message in the chat log
+        using the provided help text as the message object and
+        `help` as the user. This is useful for providing instructions,
+        and will not be included in the `serialize` method by default.""")
+
     placeholder_text = param.String(default="", doc="""
-        If placeholder is the default LoadingSpinner the text to display
-        next to it.""")
+        The text to display next to the placeholder icon.""")
+
+    placeholder_params = param.Dict(default={
+        "user": " ", "reaction_icons": {}, "show_copy_icon": False, "show_timestamp": False
+    }, doc="""
+        Params to pass to the placeholder ChatMessage, like `reaction_icons`,
+        `timestamp_format`, `show_avatar`, `show_user`, `show_timestamp`.
+        """
+    )
 
     placeholder_threshold = param.Number(default=1, bounds=(0, None), doc="""
         Min duration in seconds of buffering before displaying the placeholder.
@@ -196,6 +155,11 @@ class ChatFeed(ListPanel):
         exception. If None, will attempt to infer the renderer
         from the value.""")
 
+    load_buffer = param.Integer(default=50, bounds=(0, None), doc="""
+        The number of objects loaded on each side of the visible objects.
+        When scrolled halfway into the buffer, the feed will automatically
+        load additional objects while unloading objects on the opposite side.""")
+
     scroll_button_threshold = param.Integer(default=100, bounds=(0, None),doc="""
         Min pixel distance from the latest object in the Column to
         display the scroll button. Setting to 0
@@ -216,7 +180,9 @@ class ChatFeed(ListPanel):
     _callback_state = param.ObjectSelector(objects=list(CallbackState), doc="""
         The current state of the callback.""")
 
-    _was_disabled = param.Boolean(default=False, doc="""
+    _callback_trigger = param.Event(doc="Triggers the callback to respond.")
+
+    _disabled_stack = param.List(doc="""
         The previous disabled state of the feed.""")
 
     _stylesheets: ClassVar[List[str]] = [f"{CDN_DIST}css/chat_feed.css"]
@@ -231,13 +197,16 @@ class ChatFeed(ListPanel):
 
         # forward message params to ChatMessage for convenience
         message_params = params.get("message_params", {})
-        for param_key in list(params.keys()):
-            if param_key not in ChatFeed.param and param_key in ChatMessage.param:
+        for param_key in params.copy():
+            if param_key not in self.param and param_key in ChatMessage.param:
                 message_params[param_key] = params.pop(param_key)
         params["message_params"] = message_params
 
         super().__init__(*objects, **params)
 
+        if self.help_text:
+            self.objects = [ChatMessage(self.help_text, user="Help"), *self.objects]
+
         # instantiate the card's column
         linked_params = dict(
             design=self.param.design,
@@ -248,14 +217,17 @@ class ChatFeed(ListPanel):
             visible=self.param.visible
         )
         # we separate out chat log for the auto scroll feature
-        self._chat_log = Column(
-            *objects,
+        self._chat_log = Feed(
+            *self.objects,
+            load_buffer=self.load_buffer,
             auto_scroll_limit=self.auto_scroll_limit,
             scroll_button_threshold=self.scroll_button_threshold,
+            view_latest=self.view_latest,
             css_classes=["chat-feed-log"],
             stylesheets=self._stylesheets,
             **linked_params
         )
+        self._chat_log.height = None
         card_params = linked_params.copy()
         card_stylesheets = (
             self._stylesheets +
@@ -265,7 +237,7 @@ class ChatFeed(ListPanel):
         card_params.update(
             margin=self.param.margin,
             align=self.param.align,
-            header=self.header,
+            header=self.param.header,
             height=self.param.height,
             hide_header=self.param.header.rx().rx.in_((None, "")),
             collapsible=False,
@@ -289,8 +261,7 @@ class ChatFeed(ListPanel):
         )
 
         # handle async callbacks using this trick
-        self._callback_trigger = Button(visible=False)
-        self._callback_trigger.on_click(self._prepare_response)
+        self.param.watch(self._prepare_response, '_callback_trigger')
 
     def _get_model(
         self, doc: Document, root: Model | None = None,
@@ -311,28 +282,29 @@ class ChatFeed(ListPanel):
         self._card._cleanup(root)
         super()._cleanup(root)
 
+    @param.depends("load_buffer", "auto_scroll_limit", "scroll_button_threshold", watch=True)
+    def _update_chat_log_params(self):
+        self._chat_log.load_buffer = self.load_buffer
+        self._chat_log.auto_scroll_limit = self.auto_scroll_limit
+        self._chat_log.scroll_button_threshold = self.scroll_button_threshold
+
     @param.depends("card_params", watch=True)
     def _update_card_params(self):
         card_params = self.card_params.copy()
         card_params.pop('stylesheets', None)
         self._card.param.update(**card_params)
 
-    @param.depends("placeholder_text", watch=True, on_init=True)
+    @param.depends("placeholder_text", "placeholder_params", watch=True, on_init=True)
     def _update_placeholder(self):
-        if self._placeholder is not None:
-            self._placeholder.param.update(object=self.placeholder_text)
-            return
-
         loading_avatar = SVG(
-            PLACEHOLDER_SVG, sizing_mode=None, css_classes=["rotating-placeholder"]
+            PLACEHOLDER_SVG, sizing_mode="fixed", width=35, height=35,
+            css_classes=["rotating-placeholder"]
         )
         self._placeholder = ChatMessage(
             self.placeholder_text,
-            user=" ",
-            show_timestamp=False,
             avatar=loading_avatar,
-            reaction_icons={},
-            show_copy_icon=False,
+            css_classes=["message"],
+            **self.placeholder_params
         )
 
     def _replace_placeholder(self, message: ChatMessage | None = None) -> None:
@@ -484,24 +456,42 @@ class ChatFeed(ListPanel):
         start = asyncio.get_event_loop().time()
         while not task.done() and num_entries == len(self._chat_log):
             duration = asyncio.get_event_loop().time() - start
-            if duration > self.placeholder_threshold:
+            if duration > self.placeholder_threshold or self._callback_future is None:
                 self.append(self._placeholder)
                 return
             await asyncio.sleep(0.1)
 
-    async def _handle_callback(self, message, loop):
+    async def _to_async_gen(self, sync_gen):
+        done = object()
+
+        def safe_next():
+            # Converts StopIteration to a sentinel value to avoid:
+            # TypeError: StopIteration interacts badly with generators and cannot be raised into a Future
+            try:
+                return next(sync_gen)
+            except StopIteration:
+                return done
+
+        while True:
+            value = await asyncio.to_thread(safe_next)
+            if value is done:
+                break
+            yield value
+
+    async def _handle_callback(self, message, loop: asyncio.BaseEventLoop):
         callback_args = self._gather_callback_args(message)
         if iscoroutinefunction(self.callback):
             response = await self.callback(*callback_args)
         elif isasyncgenfunction(self.callback):
             response = self.callback(*callback_args)
+        elif isgeneratorfunction(self.callback):
+            response = self._to_async_gen(self.callback(*callback_args))
+            # printing type(response) -> <class 'async_generator'>
         else:
-            response = await loop.run_in_executor(
-                None, partial(self.callback, *callback_args)
-            )
+            response = await asyncio.to_thread(self.callback, *callback_args)
         await self._serialize_response(response)
 
-    async def _prepare_response(self, _) -> None:
+    async def _prepare_response(self, *_) -> None:
         """
         Prepares the response by scheduling the placeholder and
         executing the callback.
@@ -509,7 +499,7 @@ class ChatFeed(ListPanel):
         if self.callback is None:
             return
 
-        self._was_disabled = self.disabled
+        self._disabled_stack.append(self.disabled)
         try:
             with param.parameterized.batch_call_watchers(self):
                 self.disabled = True
@@ -553,7 +543,7 @@ class ChatFeed(ListPanel):
         with param.parameterized.batch_call_watchers(self):
             self._replace_placeholder(None)
             self._callback_state = CallbackState.IDLE
-            self.disabled = self._was_disabled
+            self.disabled = self._disabled_stack.pop() if self._disabled_stack else False
 
     # Public API
 
@@ -602,10 +592,11 @@ class ChatFeed(ListPanel):
 
     def stream(
         self,
-        value: str,
+        value: str | dict | ChatMessage,
         user: str | None = None,
         avatar: str | bytes | BytesIO | None = None,
         message: ChatMessage | None = None,
+        replace: bool = False,
     ) -> ChatMessage | None:
         """
         Streams a token and updates the provided message, if provided.
@@ -626,6 +617,8 @@ class ChatFeed(ListPanel):
             The avatar to use; overrides the message's avatar if provided.
         message : ChatMessage | None
             The message to update.
+        replace : bool
+            Whether to replace the existing text when streaming a string or dict.
 
         Returns
         -------
@@ -641,7 +634,7 @@ class ChatFeed(ListPanel):
             )
         elif message:
             if isinstance(value, (str, dict)):
-                message.stream(value)
+                message.stream(value, replace=replace)
                 if user:
                     message.user = user
                 if avatar:
@@ -663,7 +656,7 @@ class ChatFeed(ListPanel):
         """
         Executes the callback with the latest message in the chat log.
         """
-        self._callback_trigger.param.trigger("clicks")
+        self.param.trigger("_callback_trigger")
 
     def stop(self) -> bool:
         """
@@ -685,7 +678,7 @@ class ChatFeed(ListPanel):
             cancelled = self._callback_future.cancel()
 
         if cancelled:
-            self.disabled = self._was_disabled
+            self.disabled = self._disabled_stack.pop() if self._disabled_stack else False
             self._replace_placeholder(None)
         return cancelled
 
@@ -773,6 +766,7 @@ class ChatFeed(ListPanel):
 
     def serialize(
         self,
+        exclude_users: List[str] | None = None,
         filter_by: Callable | None = None,
         format: Literal["transformers"] = "transformers",
         custom_serializer: Callable | None = None,
@@ -786,6 +780,9 @@ class ChatFeed(ListPanel):
         format : str
             The format to export the chat log as; currently only
             supports "transformers".
+        exclude_users : list(str) | None
+            A list of user (case insensitive names) to exclude from serialization.
+            If not provided, defaults to ["help"]. This will be executed before `filter_by`.
         filter_by : callable
             A function to filter the chat log by.
             The function must accept and return a list of ChatMessage objects.
@@ -811,7 +808,15 @@ class ChatFeed(ListPanel):
         -------
         The chat log serialized in the specified format.
         """
-        messages = self._chat_log.objects.copy()
+        if exclude_users is None:
+            exclude_users = ["help"]
+        else:
+            exclude_users = [user.lower() for user in exclude_users]
+        messages = [
+            message for message in self._chat_log.objects
+            if message.user.lower() not in exclude_users
+        ]
+
         if filter_by is not None:
             messages = filter_by(messages)
 
