@@ -106,8 +106,14 @@ class FloatPanel(ListLike, ReactiveHTML):
         config = {...config, ...data.config}
         state.panel = jsPanel.create(config);
         if (data.status !== 'normalized') {
-           view.run_script('status')
+          view.run_script('status')
         }
+        state.resizeHandler = (event) => {
+          if (event.panel === state.panel) {
+            view.invalidate_layout()
+          }
+        }
+        document.addEventListener('jspanelresizestop', state.resizeHandler, false)
         """,
         "name": "state.panel.setHeaderTitle(data.name)",
         "status": """
@@ -138,7 +144,11 @@ class FloatPanel(ListLike, ReactiveHTML):
         """,
         "contained": "delete state.panel; view.invalidate_render();",
         "theme": "state.panel.setTheme(data.theme)",
-        "remove": "view.run_script('close'); state.panel = undefined;",
+        "remove": """
+        document.removeEventListener('jspanelresizestop', state.resizeHandler, false);
+        view.run_script('close');
+        state.panel = undefined;
+        """,
         "offsetx": "view.run_script('reposition')",
         "offsety": "view.run_script('reposition')",
         "position": "if (!data.contained) { view.run_script('reposition') }",
