@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from collections import OrderedDict
 from typing import ClassVar, List, Mapping
 
 import param
@@ -163,7 +162,7 @@ class GridStack(ReactiveHTML, GridSpec):
 
     @param.depends('state', watch=True)
     def _update_objects(self):
-        objects = OrderedDict()
+        objects = {}
         object_ids = {str(id(obj)): obj for obj in self}
         for p in self.state:
             objects[(p['y0'], p['x0'], p['y1'], p['x1'])] = object_ids[p['id']]
