@@ -2,8 +2,11 @@ export {AcePlot} from "./ace"
 export {Audio} from "./audio"
 export {BrowserInfo} from "./browser"
 export {Button} from "./button"
+export {ButtonIcon} from "./button_icon"
+export {ClickableIcon} from "./icon"
 export {Card} from "./card"
 export {CheckboxButtonGroup} from "./checkbox_button_group"
+export {ChatAreaInput} from "./chatarea_input"
 export {Column} from "./column"
 export {CommManager} from "./comm_manager"
 export {CustomSelect} from "./customselect"
@@ -11,6 +14,7 @@ export {DataTabulator} from "./tabulator"
 export {DatetimePicker} from "./datetime_picker"
 export {DeckGLPlot} from "./deckgl"
 export {ECharts} from "./echarts"
+export {Feed} from "./feed"
 export {FileDownload} from "./file_download"
 export {HTML} from "./html"
 export {IPyWidget} from "./ipywidget"
@@ -34,7 +38,7 @@ export {Tabs} from "./tabs"
 export {Terminal} from "./terminal"
 export {TextAreaInput} from "./textarea_input"
 export {TextToSpeech} from "./text_to_speech"
-export {ToggleIcon} from "./icon"
+export {ToggleIcon} from "./toggle_icon"
 export {TooltipIcon} from "./tooltip_icon"
 export {TrendIndicator} from "./trend"
 export {VegaPlot} from "./vega"
