@@ -14,7 +14,7 @@ from panel.io.embed import embed_state
 from panel.pane import Str
 from panel.param import Param
 from panel.widgets import (
-    Checkbox, FloatSlider, IntSlider, Select, StaticText,
+    Checkbox, EditableFloatSlider, FloatSlider, IntSlider, Select, StaticText,
 )
 
 
@@ -92,7 +92,6 @@ def test_embed_select_str_link(document, comm):
         assert event['model'] == model.children[1].ref
         assert event['new'] == '&lt;pre&gt;%s&lt;/pre&gt;' % k
 
-
 def test_embed_float_slider_explicit_values(document, comm):
     select = FloatSlider()
     string = Str()
@@ -122,6 +121,44 @@ def test_embed_float_slider_explicit_values(document, comm):
         assert event2['model'] == model.children[1].ref
         assert event2['new'] == '&lt;pre&gt;%s&lt;/pre&gt;' % states[k]
 
+def test_embed_editable_float_slider_explicit_values(document, comm):
+    select = EditableFloatSlider()
+    string = Str()
+    def link(target, event):
+        target.object = event.new
+    select.link(string, callbacks={'value': link})
+    panel = Row(select, string)
+    with config.set(embed=True):
+        model = panel.get_root(document, comm)
+    embed_state(panel, model, document, states={select: [0.1, 0.7, 1]})
+    _, state = document.roots
+    assert set(state.state) == {0, 1, 2}
+    states = {0: 0.1, 1: 0.7, 2: 1}
+    for (k, v) in state.state.items():
+        content = json.loads(v['content'])
+        assert 'events' in content
+        events = content['events']
+        assert len(events) == 4
+        event1, event2, event3, event4 = events
+        assert event1['kind'] == 'ModelChanged'
+        assert event1['attr'] == 'text'
+        assert event1['model'] == model.children[0].children[1].children[0].ref
+        assert event1['new'] == '<b>%s</b>' % states[k]
+
+        assert event2['kind'] == 'ModelChanged'
+        assert event2['attr'] == 'value'
+        assert event2['new'] == states[k]
+
+        assert event3['kind'] == 'ModelChanged'
+        assert event3['attr'] == 'value'
+        assert event3['model'] == model.children[0].children[0].children[1].ref
+        assert event3['new'] == states[k]
+
+        assert event4['kind'] == 'ModelChanged'
+        assert event4['attr'] == 'text'
+        assert event4['model'] == model.children[1].ref
+        assert event4['new'] == f'&lt;pre&gt;{states[k]}&lt;/pre&gt;'
+
 def test_embed_float_slider_default_value(document, comm):
     slider = FloatSlider(start=0, end=7.2, value=3.6)
     string = Str()
@@ -136,6 +173,20 @@ def test_embed_float_slider_default_value(document, comm):
     assert set(state.state) == {0, 1, 2}
     assert layout.children[0].children[1].value == 1
 
+def test_embed_editable_float_slider_default_value(document, comm):
+    slider = EditableFloatSlider(start=0, end=7.2, value=3.6)
+    string = Str()
+    def link(target, event):
+        target.object = event.new
+    slider.link(string, callbacks={'value': link})
+    panel = Row(slider, string)
+    with config.set(embed=True):
+        model = panel.get_root(document, comm)
+    embed_state(panel, model, document)
+    layout, state = document.roots
+    assert set(state.state) == {0, 1, 2}
+    assert layout.children[0].children[1].children[1].value == 1
+
 def test_embed_select_explicit_values(document, comm):
     select = Select(options=['A', 'B', 'C'])
     string = Str()
