@@ -1,3 +1,7 @@
+import sys
+
+from pathlib import Path
+
 import pytest
 
 pytest.importorskip("playwright")
@@ -34,7 +38,8 @@ def test_jupyter_server_custom_resources(page, jupyter_preview):
 def test_jupyter_server_kernel_error(page, jupyter_preview):
     page.goto(f"{jupyter_preview}/app.py?kernel=blah", timeout=30000)
 
-    assert page.text_content('#subtitle') == "Kernel error: No such kernel 'blah'"
+    expect(page.locator('#error-type')).to_have_text("Kernel Error")
+    expect(page.locator('#error')).to_have_text("No such kernel 'blah'")
 
     page.select_option('select#kernel-select', 'python3')
 
@@ -49,3 +54,9 @@ def test_jupyter_server_session_arg_theme(page, jupyter_preview):
     page.goto(f"{jupyter_preview}/app.py?theme=dark", timeout=30000)
 
     expect(page.locator('body')).to_have_css('color', 'rgb(0, 0, 0)')
+
+
+def test_jupyter_config():
+    # If this test fails, run `pip install -e .` again
+    jp_files = (Path(sys.prefix) / 'etc' / 'jupyter').rglob('panel-client-jupyter.json')
+    assert len(list(jp_files)) == 2
