@@ -105,6 +105,6 @@ def test_gauge_bounds():
 def test_tqdm_color():
     tqdm = Tqdm()
     tqdm.text_pane.styles={'color': 'green'}
-    for _ in tqdm(range(0,2)):
+    for _ in tqdm(range(2)):
         pass
     assert tqdm.text_pane.styles["color"]=="green"
