@@ -15,7 +15,7 @@ from bokeh.themes import Theme as _BkTheme, _dark_minimal, built_in_themes
 
 from ..config import config
 from ..io.resources import (
-    ResourceComponent, component_resource_path, get_dist_path,
+    JS_VERSION, ResourceComponent, component_resource_path, get_dist_path,
     resolve_custom_path,
 )
 from ..util import relative_to
@@ -348,7 +348,10 @@ class Design(param.Parameterized, ResourceComponent):
             theme.apply_to_model(sm)
 
     def resolve_resources(
-        self, cdn: bool | Literal['auto'] = 'auto', include_theme: bool = True
+        self,
+        cdn: bool | Literal['auto'] = 'auto',
+        extras: dict[str, dict[str, str]] | None = None,
+        include_theme: bool = True
     ) -> ResourceTypes:
         """
         Resolves the resources required for this design component.
@@ -359,6 +362,9 @@ class Design(param.Parameterized, ResourceComponent):
             Whether to load resources from CDN or local server. If set
             to 'auto' value will be automatically determine based on
             global settings.
+        extras: dict[str, dict[str, str]] | None
+            Additional resources to add to the bundle. Valid resource
+            types include js, js_modules and css.
         include_theme: bool
             Whether to include theme resources.
 
@@ -366,10 +372,11 @@ class Design(param.Parameterized, ResourceComponent):
         -------
         Dictionary containing JS and CSS resources.
         """
-        resource_types = super().resolve_resources(cdn)
+        resource_types = super().resolve_resources(cdn=cdn, extras=extras)
         if not include_theme:
             return resource_types
         dist_path = get_dist_path(cdn=cdn)
+        version_suffix = f'?v={JS_VERSION}'
         css_files = resource_types['css']
         theme = self.theme
         for attr in ('base_css', 'css'):
@@ -379,7 +386,7 @@ class Design(param.Parameterized, ResourceComponent):
             basename = os.path.basename(css)
             key = 'theme_base' if 'base' in attr else 'theme'
             if relative_to(css, THEME_CSS):
-                css_files[key] = dist_path + f'bundled/theme/{basename}'
+                css_files[key] = dist_path + f'bundled/theme/{basename}{version_suffix}'
             elif resolve_custom_path(theme, css):
                 owner = type(theme).param[attr].owner
                 css_files[key] = component_resource_path(owner, attr, css)
