@@ -42,12 +42,9 @@ from .parameters import (  # noqa
 
 log = logging.getLogger('panel.util')
 
-bokeh_version = Version(bokeh.__version__)
-
-# Bokeh serializes NaT as this value
-# Discussion on why https://github.com/bokeh/bokeh/pull/10449/files#r479988469
-BOKEH_JS_NAT = -9223372036854776.0
+bokeh_version = Version(Version(bokeh.__version__).base_version)
 
+BOKEH_JS_NAT = np.nan
 PARAM_NAME_PATTERN = re.compile(r'^.*\d{5}$')
 
 class LazyHTMLSanitizer:
@@ -469,11 +466,14 @@ def styler_update(styler, new_df):
                 continue
             op_fn = str(op[0])
             if ('_background_gradient' in op_fn or '_bar' in op_fn) and op[1] in (0, 1):
-                applies = np.array([
-                    new_df[col].dtype.kind in 'uif' for col in new_df.columns
-                ])
-                if len(op[2]) == len(applies):
-                    applies = np.logical_and(applies, op[2])
+                if isinstance(op[2], list):
+                    applies = op[2]
+                else:
+                    applies = np.array([
+                        new_df[col].dtype.kind in 'uif' for col in new_df.columns
+                    ])
+                    if len(op[2]) == len(applies):
+                        applies = np.logical_and(applies, op[2])
                 op = (op[0], op[1], applies)
             ops.append(op)
         todo = tuple(ops)
